@@ -24,11 +24,13 @@ crepuscule = ['#3c8588',
              '#dbad4e',
              '#efedce',]
 
-juniper = ['#b1516a',
-            '#af9c85',
-            '#bbc9a2',
-            '#ebd5a2',
-            '#595353']
+juniper = ['#237683',
+            '#C9375B',
+            '#35477D',
+            '#cd5c5c',
+            '#FB9E91',
+            '#8A6086',
+           ]
 
 plath = ['#30343f',
            '#a84b43',
@@ -89,13 +91,17 @@ gremlin = ['#3a5b84',
            '#836a00',
            '#002c59']
 
-pollen = ["#fB9e91",
-          "#461a84",
-          "#f5f0e3",
-          "#b4b6d8",
-          '#ffd082',
-#         '#9dab86',
-         ]
+pollen = ['#fB9e91',
+          '#604d89',
+          '#f5f0e3',
+          '#b4b6d8',
+          '#ffd082']
+
+bollen = ['#eB8e81',
+        '#503d79',
+        '#c1b6b2',
+        '#a9b0d0',
+        '#efc072']
 
 medium = ['#e3a201',
           '#6762ab',
@@ -116,13 +122,22 @@ polya = ["#A43955",
          "#738C79",
          "#ECBE13"]
 
-ostrich = [ # turn alpha on
-    "navy",
-    "orangered",
-    "teal",
-    "midnightblue",
-    '#d45d79',
-    ]
+ostrich = ['#ee5500', 'teal', 'midnightblue', '#d45d79'] # TURN ALPHA ON
+
+quinone =  [
+            "#991a40",
+            "#1c0517",
+            "#9db0bb",
+            "#ae3f03",
+            (210, 150, 160)
+           ]
+
+quinoline = [
+            "#B22c56",
+            "#2c1527",
+            "#ca6f13",
+            (225, 170, 170),
+           ]
 
 fraiche = ['#472b62',
            "#f5f0e3",
@@ -447,8 +462,7 @@ pugsley = ['#eadca3',
            '#911501',
            '#07093e']
 
-bellhooks = ['#100a0b',
-             '#facab6',
+bellhooks = ['#facab6',
              '#b38577',
              '#d66f31',
              '#2e211f']
@@ -522,14 +536,11 @@ yoshi = ["#111129",
          "#cd355c",
          "#d0e44e"]
 
-phoebe = ["#f71237",
-          "#1c0517",
-          "#8ba794",
-          "#fe5f8e",
-          "#fde4d1",
-          "#991a40",
-          "#eeecec",
-         ]
+phoebe = ['#1c0517',
+          '#8ba794',
+          '#ee5f8e',
+          '#fde4d1',
+          '#991a40',]
 
 pam = ["#634131",
        "#448168",
@@ -699,6 +710,480 @@ bluefish = ['#000080',
             '#de7173',
             '#fa8072']
 
+peanuts = ["#d11026",
+            "#f0a46b",
+            "#000221"]
+
+naval = ["navy",
+        "darkorange",
+        "#a6b1e1"]
+
+maggie = ["#091622",
+          "#790C03",
+          "#d9906c",
+          "#C0340D",
+          "#838472",
+          "#feca82",
+          ]
+
+indomie = ['#ab5439',
+           '#cfa26b',
+           '#728162',
+           '#adafad',
+           '#552d1d',
+           '#e5ded5',]
+
+moonbow = ["#FF657A",
+            "#FF9B5E",
+            "#FFD76D",
+            "#9CD1BB",
+            "#BAD761",
+            "#C29AC8",
+            "#888D94"]
+
+roosh = ['#b2a9b1',
+        '#3b8988',
+        '#00104b',
+        '#a54a5c',
+        '#65658e']
+
+seafare = ['#d5622b',
+            '#153c63',
+            '#5cb8d8',
+            '#f0f5f4',
+            '#317497']
+
+heliotrope = ['#f3b8c1',
+            '#4a1248',
+            '#8c85d1',
+            '#171d6b',
+            '#cd9fba']
+
+perl256 = ['#1c2641',
+ '#1c2742',
+ '#1d2843',
+ '#1d2944',
+ '#1e2a46',
+ '#1e2b47',
+ '#1f2d48',
+ '#1f2e4a',
+ '#202f4b',
+ '#20304c',
+ '#21314d',
+ '#21324f',
+ '#223450',
+ '#223551',
+ '#233653',
+ '#243754',
+ '#243855',
+ '#253956',
+ '#253b58',
+ '#263c59',
+ '#263d5a',
+ '#273e5c',
+ '#273f5d',
+ '#28405e',
+ '#284260',
+ '#294361',
+ '#294462',
+ '#2a4563',
+ '#2b4665',
+ '#2b4766',
+ '#2c4967',
+ '#2c4a69',
+ '#2d4b6a',
+ '#2d4c6b',
+ '#2e4d6c',
+ '#2e4e6e',
+ '#2f506f',
+ '#2f5170',
+ '#305272',
+ '#305373',
+ '#315474',
+ '#325676',
+ '#335777',
+ '#355978',
+ '#365b7a',
+ '#385d7b',
+ '#3a5f7d',
+ '#3b607e',
+ '#3d6280',
+ '#3e6481',
+ '#406683',
+ '#426884',
+ '#436986',
+ '#456b87',
+ '#466d89',
+ '#486f8a',
+ '#4a718b',
+ '#4b728d',
+ '#4d748e',
+ '#4e7690',
+ '#507891',
+ '#527a93',
+ '#537b94',
+ '#557d96',
+ '#577f97',
+ '#588199',
+ '#5a839a',
+ '#5b849c',
+ '#5d869d',
+ '#5f889e',
+ '#608aa0',
+ '#628ca1',
+ '#638da3',
+ '#658fa4',
+ '#6791a6',
+ '#6893a7',
+ '#6a95a9',
+ '#6b96aa',
+ '#6d98ac',
+ '#6f9aad',
+ '#709caf',
+ '#729eb0',
+ '#74a0b2',
+ '#76a0b2',
+ '#78a0b3',
+ '#7ba1b4',
+ '#7da1b4',
+ '#7fa2b5',
+ '#82a2b6',
+ '#84a3b6',
+ '#86a3b7',
+ '#89a4b8',
+ '#8ba4b9',
+ '#8da5b9',
+ '#90a5ba',
+ '#92a6bb',
+ '#94a6bb',
+ '#97a6bc',
+ '#99a7bd',
+ '#9ba7be',
+ '#9ea8be',
+ '#a0a8bf',
+ '#a2a9c0',
+ '#a5a9c0',
+ '#a7aac1',
+ '#a9aac2',
+ '#acabc2',
+ '#aeabc3',
+ '#b0acc4',
+ '#b3acc5',
+ '#b5acc5',
+ '#b7adc6',
+ '#baadc7',
+ '#bcaec7',
+ '#beaec8',
+ '#c1afc9',
+ '#c3afca',
+ '#c5b0ca',
+ '#c8b0cb',
+ '#cab1cc',
+ '#ccb1cc',
+ '#cfb2cd',
+ '#d1b2ce',
+ '#d4b3cf',
+ '#d3b2ce',
+ '#d2b1ce',
+ '#d1b1ce',
+ '#d0b0ce',
+ '#cfb0ce',
+ '#ceafce',
+ '#cdafcd',
+ '#ccaecd',
+ '#ccaecd',
+ '#cbadcd',
+ '#caadcd',
+ '#c9accd',
+ '#c8accd',
+ '#c7abcc',
+ '#c6aacc',
+ '#c5aacc',
+ '#c5a9cc',
+ '#c4a9cc',
+ '#c3a8cc',
+ '#c2a8cc',
+ '#c1a7cb',
+ '#c0a7cb',
+ '#bfa6cb',
+ '#bea6cb',
+ '#bea5cb',
+ '#bda5cb',
+ '#bca4cb',
+ '#bba3ca',
+ '#baa3ca',
+ '#b9a2ca',
+ '#b8a2ca',
+ '#b7a1ca',
+ '#b7a1ca',
+ '#b6a0ca',
+ '#b5a0c9',
+ '#b49fc9',
+ '#b39fc9',
+ '#b29ec9',
+ '#b19ec9',
+ '#b09dc9',
+ '#b09dc9',
+ '#ae9cc8',
+ '#ad9cc8',
+ '#ac9bc8',
+ '#ab9bc7',
+ '#aa9ac7',
+ '#a89ac7',
+ '#a799c7',
+ '#a699c6',
+ '#a599c6',
+ '#a498c6',
+ '#a398c6',
+ '#a197c5',
+ '#a097c5',
+ '#9f96c5',
+ '#9e96c4',
+ '#9d95c4',
+ '#9c95c4',
+ '#9a95c4',
+ '#9994c3',
+ '#9894c3',
+ '#9793c3',
+ '#9693c3',
+ '#9592c2',
+ '#9392c2',
+ '#9292c2',
+ '#9191c2',
+ '#9091c1',
+ '#8f90c1',
+ '#8e90c1',
+ '#8c8fc0',
+ '#8b8fc0',
+ '#8a8ec0',
+ '#898ec0',
+ '#888ebf',
+ '#878dbf',
+ '#858dbf',
+ '#848cbf',
+ '#838cbe',
+ '#828bbe',
+ '#818bbe',
+ '#808bbe',
+ '#7e89bd',
+ '#7d88bd',
+ '#7c87bc',
+ '#7b86bc',
+ '#7a85bc',
+ '#7883bb',
+ '#7782bb',
+ '#7681ba',
+ '#7580ba',
+ '#747fba',
+ '#737eb9']
+
+orb = ['#1e2422',
+       '#414146',
+       '#4f626b',
+       '#926970',
+       '#d2827d',
+       '#e7cac6']
+
+orb256 = ['#0f1211',
+ '#101312',
+ '#111413',
+ '#121514',
+ '#121615',
+ '#131716',
+ '#141817',
+ '#151918',
+ '#161a19',
+ '#171b1a',
+ '#181c1b',
+ '#181d1c',
+ '#191e1d',
+ '#1a1f1e',
+ '#1b201f',
+ '#1c2120',
+ '#1d2221',
+ '#1e2422',
+ '#1f2423',
+ '#202524',
+ '#212625',
+ '#222726',
+ '#232827',
+ '#242828',
+ '#252929',
+ '#262a2a',
+ '#272b2b',
+ '#282c2c',
+ '#292d2d',
+ '#2a2d2e',
+ '#2b2e2f',
+ '#2c2f30',
+ '#2d3031',
+ '#2e3132',
+ '#2f3233',
+ '#303234',
+ '#313335',
+ '#323436',
+ '#333537',
+ '#343638',
+ '#353739',
+ '#36373a',
+ '#37383b',
+ '#38393c',
+ '#393a3d',
+ '#3a3b3e',
+ '#3b3c3f',
+ '#3c3c40',
+ '#3d3d41',
+ '#3e3e42',
+ '#3f3f43',
+ '#404044',
+ '#414146',
+ '#414147',
+ '#414248',
+ '#424349',
+ '#42444a',
+ '#43454b',
+ '#43464c',
+ '#43474d',
+ '#44484e',
+ '#44494f',
+ '#454a50',
+ '#454b51',
+ '#454c52',
+ '#464d53',
+ '#464e54',
+ '#474f55',
+ '#475056',
+ '#475157',
+ '#485159',
+ '#48525a',
+ '#49535b',
+ '#49545c',
+ '#49555d',
+ '#4a565e',
+ '#4a575f',
+ '#4b5860',
+ '#4b5961',
+ '#4b5a62',
+ '#4c5b63',
+ '#4c5c64',
+ '#4d5d65',
+ '#4d5e66',
+ '#4d5f67',
+ '#4e6068',
+ '#4e6169',
+ '#4f626b',
+ '#50626b',
+ '#52626b',
+ '#54626b',
+ '#56626b',
+ '#58636b',
+ '#5a636b',
+ '#5c636c',
+ '#5e636c',
+ '#60636c',
+ '#62646c',
+ '#64646c',
+ '#65646c',
+ '#67646c',
+ '#69646d',
+ '#6b656d',
+ '#6d656d',
+ '#6f656d',
+ '#71656d',
+ '#73656d',
+ '#75666d',
+ '#77666e',
+ '#79666e',
+ '#7b666e',
+ '#7c666e',
+ '#7e676e',
+ '#80676e',
+ '#82676e',
+ '#84676f',
+ '#86676f',
+ '#88686f',
+ '#8a686f',
+ '#8c686f',
+ '#8e686f',
+ '#90686f',
+ '#926970',
+ '#936970',
+ '#956a70',
+ '#976b71',
+ '#996b71',
+ '#9b6c71',
+ '#9c6d72',
+ '#9e6e72',
+ '#a06e72',
+ '#a26f73',
+ '#a47073',
+ '#a67074',
+ '#a77174',
+ '#a97274',
+ '#ab7375',
+ '#ad7375',
+ '#af7475',
+ '#b17576',
+ '#b27576',
+ '#b47677',
+ '#b67777',
+ '#b87877',
+ '#ba7878',
+ '#bc7978',
+ '#bd7a78',
+ '#bf7a79',
+ '#c17b79',
+ '#c37c7a',
+ '#c57d7a',
+ '#c77d7a',
+ '#c87e7b',
+ '#ca7f7b',
+ '#cc7f7b',
+ '#ce807c',
+ '#d0817c',
+ '#d2827d',
+ '#d2847f',
+ '#d38681',
+ '#d38883',
+ '#d48a85',
+ '#d58c87',
+ '#d58e89',
+ '#d6908b',
+ '#d6928d',
+ '#d7948f',
+ '#d89691',
+ '#d89893',
+ '#d99a96',
+ '#d99c98',
+ '#da9e9a',
+ '#dba09c',
+ '#dba29e',
+ '#dca4a0',
+ '#dca7a2',
+ '#dda9a4',
+ '#deaba6',
+ '#deada8',
+ '#dfafaa',
+ '#dfb1ac',
+ '#e0b3af',
+ '#e1b5b1',
+ '#e1b7b3',
+ '#e2b9b5',
+ '#e2bbb7',
+ '#e3bdb9',
+ '#e4bfbb',
+ '#e4c1bd',
+ '#e5c3bf',
+ '#e5c5c1',
+ '#e6c7c3',
+ '#e7cac6',
+ '#e7cbc7',
+ '#e7ccc8',
+ '#e7cdc9',
+ '#e7ceca',
+ '#e8cfcb',
+ '#e8d0cc',
+ '#e8d1ce']
 
 joker = ["#133d3c",
         "#30706e",
@@ -4199,7 +4684,12 @@ betan256 = ['#73100b',
  '#595959',
  '#585858']
 
-rue = ["#973D46","#6D2A31","#CFBDBF","#5977B5","#263452","#90AAD9"]
+rue = ["#973D46",
+    "#6D2A31",
+    "#CFBDBF",
+    "#5977B5",
+    "#263452",
+    "#90AAD9"]
 rue256 = ['#000000',
  '#020101',
  '#050202',
@@ -5387,7 +5877,20 @@ all_palettes = ["selah",
                 "strogatz",
                 "lutz",
                 "writhe",
+                "peanuts",
+                "naval",
+                "maggie",
+                "indomie",
+                "mooonbow",
+                "heliotrope",
+                "roosh",
+                "seafare",
+                "quinone",
+                "quinoline",
                 "perl",
+                "perl256",
+                "orb",
+                "orb256"
                 "diverging",
                 "bluefish",
                 "joan256",
