@@ -212,6 +212,17 @@ palette_dict = {
     "lutz":lutz,
     "writhe":writhe,
     "perl":perl,
+    "roosh": roosh,
+    "seafare": seafare,
+    "heliotrope": heliotrope,
+    "moonbow": moonbow,
+    "peanuts": peanuts,
+    "naval": naval,
+    "quinone":quinone,
+    "quinoline":quinoline,
+    "indomie": indomie,
+    "maggie": maggie,
+    "orb": orb,
     "diverging":diverging,
     "warble":warble,
     "waitomo":waitomo,
@@ -318,8 +329,11 @@ def hsl_to_rgb(palette):
     if type(palette[0])==float: return _hsl_to_rgb(palette)
     return [_hsl_to_rgb(color) for color in palette]
 
-
-
+def luminance_sort(rgb):
+    weights = np.array([0.2126, 0.7152, 0.0722])
+    lum = [sum(np.array(list(c)) * weights) for c in rgb]
+    rgb_sort = [x for _, x in sorted(zip(lum, rgb))]
+    return rgb_sort
 
 def hex_palette(palette):
     ''' REFORMATTING INPUT PALETTE ..........'''
